summaryrefslogtreecommitdiff
path: root/scripts/config.sh
diff options
context:
space:
mode:
authorPaul Buetow <paul@buetow.org>2013-04-06 13:14:43 +0200
committerPaul Buetow <paul@buetow.org>2013-04-06 13:14:43 +0200
commit312fe18cb5f97143f3600b207e979bc559256b6f (patch)
treede14514b4b4c20adf0eecdcd261ae21839f6a645 /scripts/config.sh
parentf038883a6e004eb4312ba1e761da06b596e14d3f (diff)
tagging yhttpd-0.7.0yhttpd-0.7.0
Diffstat (limited to 'scripts/config.sh')
-rwxr-xr-xscripts/config.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/config.sh b/scripts/config.sh
index 373fad4..f301246 100755
--- a/scripts/config.sh
+++ b/scripts/config.sh
@@ -1,5 +1,5 @@
#!/bin/sh
# The yChat Project (2004)
#
# This script modifues the src/glob.h file.
@@ -15,11 +15,11 @@ perl -e '
use scripts::modules::file;
print <<END;
-Welcome to the yChat configurator!
+Welcome to the yhttpd configurator!
You may also edit the src/glob.h file manually instead of using
this configurator option. Please also notice that this are only
before-compile options. All setups which can be made after com-
-iling are placed in the yChat configuration file.
+iling are placed in the yhttpd configuration file.
END
my $sep = "================================================================\n"; my $stdin;
@@ -1,5 +1,5 @@
#!/bin/sh
-# The yChat Project (2004)
+# The yhttpd Project (2004)
#
# This script modifues the src/glob.h file.